@@ -5,6 +5,8 @@ import uuid
 from typing import List, Dict, Text, NoReturn
 from urllib.parse import unquote
 
+import demjson
+
 try:
     import allure
 
@@ -220,11 +222,21 @@ class HttpRunner(object):
         parsed_request_dict["allure"] = a
         # request
         resp = self.__session.request(method, url, **parsed_request_dict)
-        if USE_ALLURE:
-            # update allure report meta
-            allure.attach(a.curl, "curl:", allure.attachment_type.TEXT)
         resp_obj = ResponseObject(resp)
         step.variables["response"] = resp_obj
+        if USE_ALLURE:
+            # update allure report meta
+            allure.attach(str(resp_obj.resp_obj.status_code), "状态码:", allure.attachment_type.TEXT)
+            try:
+                if resp_obj.resp_obj.text is not None and resp_obj.resp_obj.text != "":
+                    value = demjson.decode(resp_obj.resp_obj.text)
+                    if "code" in value:
+                        allure.attach(str(value["code"]), "code:", allure.attachment_type.TEXT)
+                    if "msg" in value:
+                        allure.attach(str(value["msg"]), "msg:", allure.attachment_type.TEXT)
+            except:
+                pass
+            allure.attach(a.curl, "curl:", allure.attachment_type.TEXT)
 
         def log_req_resp_details():
             err_msg = "\n{} DETAILED REQUEST & RESPONSE {}\n".format("*" * 32, "*" * 32)
@@ -509,12 +521,15 @@ class HttpRunner(object):
         self.__config.name = parse_data(
             self.__config.name, config_variables, self.__project_meta.functions
         )
-        url = str(self.__config.base_url if self.__config.base_url[-1] != "/" else self.__config.base_url[0:-2]) + str(
-            self.__teststeps[0].request.url)
         if USE_ALLURE:
             # update allure report meta
             allure.dynamic.title(self.__config.name)
-            allure.dynamic.description(f"URL:{url}")
+            if self.__teststeps[-1].request is not None:
+                requestUrl = self.__teststeps[-1].request.url
+                url = str(self.__config.base_url if self.__config.base_url[-1] != "/" else self.__config.base_url[
+                                                                                           0:-2]) + str(
+                    requestUrl)
+                allure.dynamic.description(f"URL:{url}")
 
         logger.info(
             f"Start to run testcase: {self.__config.name}, TestCase ID: {self.__case_id}"
